from .apt import AptManager
from .base import PackageManager
from .basher import BasherManager
from .brew import HomebrewManager
from .cargo import CargoManager
from .gem import GemManager
from .ghcli import GhCliManager
from .go import GoManager
from .krew import KubectlKrewManager
from .micro import MicroEditorManager
from .npm import NpmManager
from .pip import PipManager
from .pipx import PipxManager
from .pkgx import PkgxManager
from .tldr import TldrManager
from .uv import UvManager
from .vagrant import VagrantPluginManager

__all__ = [
    "PackageManager",
    "AptManager",
    "BasherManager",
    "HomebrewManager",
    "CargoManager",
    "GemManager",
    "GhCliManager",
    "GoManager",
    "KubectlKrewManager",
    "MicroEditorManager",
    "NpmManager",
    "PipManager",
    "PipxManager",
    "PkgxManager",
    "VagrantPluginManager",
    "TldrManager",
    "UvManager",
]
